
import importlib
def collab_install_git_dependencies(
    DEPENDENCIES,
) -> str:
    """Install dependencies in Google Collab.

    Example
    -------
    DEPENDENCIES=[
        ("name", "github.com/user/repo.git@RELEASE"),
        ("notebook_utils", f"github.com/sbland/notebook_utils/archive/main.zip"),
    ]
    """
    for name, path in DEPENDENCIES:
        try:
            importlib.import_module(name)
        except (ImportError, ModuleNotFoundError):
            if 'google.colab' in str(get_ipython()):
                try:
                    print('Running on CoLab')
                    print("""
                    This notebook requires access to private repositories. To access follow the steps below:
                    1. Get an access key from your github account: https://docs.github.com/en/github/authenticating-to-github/creating-a-personal-access-token
                    2. Save the key to a file in the following location on your google drive: `My Drive/access/collabaccess.txt`. The file should include your user on the first line and your token on the second.
                    """)
                    from google.colab import drive
                    drive.mount('/content/drive')

                    !mkdir -p ~/.access
                    !cp "/content/drive/My Drive/access/collabaccess.txt" ~/.access/config
                    import os
                    creds = open(f'{os.path.expanduser("~")}/.access/config')
                    creds_parsed = creds.read().splitlines()
                    user, token = creds_parsed

                    print(f"------ Installing {name}----------------")
                    try:
                        stdout = !pip install https://{user}:{token}@{path} --ignore-requires-python
                        if "Host key verification failed" in "\n".join(stdout):
                            print(f"------------- Failed to install with dependencies for {name} ---------------")
                            # If it fails to install try installing without dependencies
                            # git+ssh dependencies will currently fail
                            !pip install https://{user}:{token}@{path} --no-deps --ignore-requires-python
                    except:
                        print(f"Failed to install all of {name} at {path}")
                    finally:
                        print("\n".join(stdout))
                    creds.close()
                except:
                    print("=======FAILED TO INSTALL ADDTIONAL DEPENDENCIES!=======\nCheck instructions above")
    creds = None
    creds_parsed = None
    user = None
    token = None


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="notebook_utils",
    version="0.2.0",
    author="Sam Bland",
    author_email="sbland.co.uk@gmail.com",
    description="Python jupyter notebook helper utilities",
    install_requires=[
        'wheel',
        'scipy',
        'numpy',
        'pandas',
        'matplotlib',
        'deprecated',
    ],
    setup_requires=[
        'wheel',
        'pytest-cov',
        'pytest-runner',
        'snapshottest'
    ],
    tests_require=['pytest', 'numpy', 'pandas', 'matplotlib', 'pytest-benchmark'],
    extras_require={'test': ['pytest', 'numpy', 'pandas']},
    packages=setuptools.find_packages(),
    package_dir={'notebook_utils': 'notebook_utils'},
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
)



# SETUP INTERACTIVE WIDGETS
# @title Setup interactive
# @markdown code hidden

from functools import wraps
import ipywidgets as widgets
from IPython.display import display


def reset_button(defaults={}):
    def on_button_clicked(_):
        for k, v in defaults.items():
            k.value = v
    button = widgets.Button(description='Reset')
    button.on_click(on_button_clicked)
    display(button)


def add_label(w, label):
    return widgets.HBox([widgets.Label(label), w], layout={'width': '800px'})


def interact_plus_reset(**_widgets):
    default_vals = {wid: wid._trait_values['value'] for k, wid in _widgets.items()}
    reset_button(defaults=default_vals)

    def wrap(func):
        abox = widgets.VBox(list([add_label(v, k)
                            for k, v in _widgets.items()]), layout={'width': 'max-content'})

        @wraps(func)
        def inner(*args, **kwargs):
            return func(**args, **kwargs)
        display(abox, widgets.interactive_output(func, _widgets))
        return inner
    return wrap

# EXAMPLE
# @interact_plus_reset(
#   foo_with_really_really_long_name=widgets.FloatSlider(min=0, max=1, value=0.3, step=0.1),
#   bar=widgets.FloatSlider(min=0, max=1, value=0.3, step=0.1),
# )
# def get_leaf_f_phen(
#     foo_with_really_really_long_name,
#     bar,
#   ):
#   print(foo_with_really_really_long_name, bar)
